

# Dosie Search Engine
## A personal search engine
## Updates

 - Added a notification feature
 - Fixed GUI full-screen bug
 - Updated desktop icon creation command
 - Other internal improvements
 - Dosie now monitors the app usage (active usage, search frequency,bug report). No personal data or information is attached to the data. **You are not personally being tracked!**

This project created a desktop search engine app which allows casual searchers and researches to find authentic, relevant, unfiltered, and referenced information with speed, security and privacy.

With the increase in advocating for data privacy, information transparency and the need for authenticity of news and information, the need for a platform or service to solve this issue has opened up. Truth and knowledge has always been a fundamental part of growth, development and the shaping of society, but in these times profitability has been found in withholding and manipulation of information. Dosie hopes to find better in the release and transparency of information. Giving the power to the consumers, and not the distributors of information.

|**What Dosie Does**|  |
|--|--|
|Make Your Own Index| The app allows you to create a list or category of domains you will like to find specific type of information from. This is to help users establish what we call a "**Network Of Trust**"|
|Find Information| **Dosie works automatically** to find, sort and categorize information. Unlike using regular search engines and a browser, and taking time to try out different search results, the app **simply does the proof-reading and verification of information** for users. The search algorithms are such that click-bait content can be vetted based on how much quality content is actually found. These results are automatically pushed down. There are configurations available for you to set limits and relevance grading for information found.|
|You Get Only What You Want| Sometimes you may be only looking for a specific and small information, instead of a 2000 word blog post. Dosie squashes all that and **gives you just the couple lines of text or image information** you want. In the occasion where you may actually be interested in reading the 2000 word post, You will be **provided a link to the main content itself**.|

##
##
##

|**What Dosie Doesn't Do**|  |
|--|--|
|Keep Your Personal Information| The app currently doesn't require any information from it's users. No email, password, credit card information or any such data. All you need to do is install the app and use it. The app may have a log in system in future and may require an email-pasword login.|
|Track Your Behavior| The app doesn't and will never pin your usage patterns and information searches to you to sell your data or show ads. We have no business or technological reasons to collect or keep such information. What the app may collect is performance data and bug reports to make sure we always know what our users want, and make useful updates. We care about your privacy.|

## Social Media
[Facebook](https://web.facebook.com/Dosie-322980288548325/?ref=br_rs)

[Instagram](https://www.instagram.com/dosie.app/)

|LINKS|  |
|--|--|
|EULA| [Dosie EULA](https://eliezerodjao.com/docs/Dosie_EULA.txt) |
|Developer | [eliezerodjaoofficial@gmail.com](mailto:eliezerodjaoofficial@gmail.com)|

Please make sure you read the **End-User License Agreement (EULA)** for this project.
By using this software, you agree to the EULA agreement.
